==> camel-k-model-v1-6.6.2-sources.jar: io/fabric8/camelk/v1/CamelArtifactExclusionFluentImpl.java <==
package io.fabric8.camelk.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CamelArtifactExclusionFluentImpl<A extends CamelArtifactExclusionFluent<A>> extends BaseFluent<A> implements CamelArtifactExclusionFluent<A>{
  public CamelArtifactExclusionFluentImpl() {
  }
  public CamelArtifactExclusionFluentImpl(CamelArtifactExclusion instance) {
    this.withArtifactId(instance.getArtifactId()); 
    this.withGroupId(instance.getGroupId()); 
  }
  private String artifactId;
  private String groupId;
  public String getArtifactId() {
    return this.artifactId;
  }
  public A withArtifactId(String artifactId) {
    this.artifactId=artifactId; return (A) this;
  }
  public Boolean hasArtifactId() {
    return this.artifactId != null;
  }
  public String getGroupId() {
    return this.groupId;
  }
  public A withGroupId(String groupId) {
    this.groupId=groupId; return (A) this;
  }
  public Boolean hasGroupId() {
    return this.groupId != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    CamelArtifactExclusionFluentImpl that = (CamelArtifactExclusionFluentImpl) o;
    if (artifactId != null ? !artifactId.equals(that.artifactId) :that.artifactId != null) return false;
    if (groupId != null ? !groupId.equals(that.groupId) :that.groupId != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(artifactId,  groupId,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (artifactId != null) { sb.append("artifactId:"); sb.append(artifactId + ","); }
    if (groupId != null) { sb.append("groupId:"); sb.append(groupId); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> camel-k-model-v1-6.7.2-sources.jar: io/fabric8/camelk/v1/CamelArtifactExclusionFluentImpl.java <==
package io.fabric8.camelk.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class CamelArtifactExclusionFluentImpl<A extends CamelArtifactExclusionFluent<A>> extends BaseFluent<A> implements CamelArtifactExclusionFluent<A>{
  public CamelArtifactExclusionFluentImpl() {
  }
  public CamelArtifactExclusionFluentImpl(CamelArtifactExclusion instance) {
    if (instance != null) {
      this.withArtifactId(instance.getArtifactId());
      this.withGroupId(instance.getGroupId());
    }
  }
  private String artifactId;
  private String groupId;
  public String getArtifactId() {
    return this.artifactId;
  }
  public A withArtifactId(String artifactId) {
    this.artifactId=artifactId; return (A) this;
  }
  public Boolean hasArtifactId() {
    return this.artifactId != null;
  }
  public String getGroupId() {
    return this.groupId;
  }
  public A withGroupId(String groupId) {
    this.groupId=groupId; return (A) this;
  }
  public Boolean hasGroupId() {
    return this.groupId != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CamelArtifactExclusionFluentImpl that = (CamelArtifactExclusionFluentImpl) o;
    if (!java.util.Objects.equals(artifactId, that.artifactId)) return false;

    if (!java.util.Objects.equals(groupId, that.groupId)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(artifactId,  groupId,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (artifactId != null) { sb.append("artifactId:"); sb.append(artifactId + ","); }
    if (groupId != null) { sb.append("groupId:"); sb.append(groupId); }
    sb.append("}");
    return sb.toString();
  }
  
}
